import requests

url = "https://jse-tracker.herokuapp.com/api/v1"


class Stocks:
    """
   The JSE class has two methods

   1. get_all
        :param: takes no parameter
        :return: all stocks in json format

   2. get
       :param: takes a list of stocks as a parameter
       :return: all stocks from the give in the list in json format

   """

    def __init__(self):
        pass

    def get_all(self):
        """
        :params: takes no parameter
        :return: all stocks
        """
        return requests.get(url).json()

    def get(self, stock):
        """
        :param: takes a list of stocks as a parameter
        :return: all stocks from the give in the list in json format
        """
        return requests.get("{}/{}".format(url, stock)).json()



from setuptools import setup, find_packages

classifiers = [
    "Development Status :: 5 - Production/Stable",
    'Intended Audience :: Developers',
    "Programming Language :: Python :: 3",
    "Operating System :: OS Independent",
    ""

]

setup(
    name="JSETracker",
    version='1.0.0',
    description="Real Time JSE stock data for free",
    long_description_content_type="text/markdown",
    long_description=open('README.md').read(),
    url="https://github.com/SNR99/JSETracker",
    author="Ntwanano Rikhotso",
    author_email="sanele.rikhotso.99@gmail.com",
    license="MIT",
    classifiers=classifiers,
    packages=find_packages(),
    keywords=["Python", "JSE", "Stock Price API", "Stock Price", "JSE API ", "Johannesburg Stock Exchange", "API",
              "Johannesburg Stock Exchange API"],
    install_requires=["bs4", "requests"]
)
